pub fn check(
source: &str,
loader: Option<&dyn LibraryLoader>,
) -> Result<Vec<Diagnostic>, Error>Expand description
Parse and semantically analyze source without bars or execution, returning
every diagnostic.
pub fn check(
source: &str,
loader: Option<&dyn LibraryLoader>,
) -> Result<Vec<Diagnostic>, Error>Parse and semantically analyze source without bars or execution, returning
every diagnostic.